diff --git a/components/modules/ai/who_human_face_detection.cpp b/components/modules/ai/who_human_face_detection.cpp
index 15b12c9..fba33af 100644
--- a/components/modules/ai/who_human_face_detection.cpp
+++ b/components/modules/ai/who_human_face_detection.cpp
@@ -11,6 +11,11 @@
 
 #define TWO_STAGE_ON 1
 
+constexpr int lcd_width = 240;
+constexpr int lcd_height = 240;
+constexpr int lcd_display_height = 180;  // For 4:3 aspect ratio
+camera_fb_t * lcd_buffer = nullptr;
+
 static const char *TAG = "human_face_detection";
 
 static QueueHandle_t xQueueFrameI = NULL;
@@ -23,6 +28,15 @@ static bool gReturnFB = true;
 
 static void task_process_handler(void *arg)
 {
+    lcd_buffer = reinterpret_cast<camera_fb_t *>(heap_caps_aligned_alloc(16, sizeof(camera_fb_t), MALLOC_CAP_8BIT));
+    lcd_buffer->height = lcd_height;
+    lcd_buffer->width = lcd_width;
+    lcd_buffer->len = 2 * lcd_buffer->width * lcd_buffer->height;
+    lcd_buffer->format = PIXFORMAT_RGB565;
+    ESP_LOGI(TAG, "Allocating %d bytes LCD buffer in external PSRAM", lcd_buffer->len);
+    lcd_buffer->buf = reinterpret_cast<uint8_t *>(heap_caps_aligned_alloc(16, lcd_buffer->len, MALLOC_CAP_8BIT | MALLOC_CAP_SPIRAM));
+    for (int i = 0; i < lcd_buffer->len; ++i) { lcd_buffer->buf[i] = 0; }
+
     camera_fb_t *frame = NULL;
     HumanFaceDetectMSR01 detector(0.3F, 0.3F, 10, 0.3F);
 #if TWO_STAGE_ON
@@ -36,6 +50,10 @@ static void task_process_handler(void *arg)
             bool is_detected = false;
             if (xQueueReceive(xQueueFrameI, &frame, portMAX_DELAY))
             {
+                dl::image::resize_image_nearest(
+                    reinterpret_cast<uint16_t *>(frame->buf), {(int)frame->height, (int)frame->width, 1},
+                    reinterpret_cast<uint16_t *>(lcd_buffer->buf), {lcd_display_height, lcd_width, 1}
+                );
 #if TWO_STAGE_ON
                 std::list<dl::detect::result_t> &detect_candidates = detector.infer((uint16_t *)frame->buf, {(int)frame->height, (int)frame->width, 3});
                 std::list<dl::detect::result_t> &detect_results = detector2.infer((uint16_t *)frame->buf, {(int)frame->height, (int)frame->width, 3}, detect_candidates);
@@ -43,6 +61,8 @@ static void task_process_handler(void *arg)
                 std::list<dl::detect::result_t> &detect_results = detector.infer((uint16_t *)frame->buf, {(int)frame->height, (int)frame->width, 3});
 #endif
 
+                esp_camera_fb_return(frame);
+
                 if (detect_results.size() > 0)
                 {
                     draw_detection_result((uint16_t *)frame->buf, frame->height, frame->width, detect_results);
@@ -53,7 +73,7 @@ static void task_process_handler(void *arg)
 
             if (xQueueFrameO)
             {
-                xQueueSend(xQueueFrameO, &frame, portMAX_DELAY);
+                xQueueSend(xQueueFrameO, &lcd_buffer, portMAX_DELAY);
             }
             else if (gReturnFB)
             {
diff --git a/components/modules/lcd/who_lcd.c b/components/modules/lcd/who_lcd.c
index 0e6ba59..eabb681 100644
--- a/components/modules/lcd/who_lcd.c
+++ b/components/modules/lcd/who_lcd.c
@@ -28,7 +28,7 @@ static void task_process_handler(void *arg)
             }
             else if (gReturnFB)
             {
-                esp_camera_fb_return(frame);
+                //esp_camera_fb_return(frame);  // done in `who_human_face_detection.cpp` instead
             }
             else
             {
